# APS_BlueSky_tools

Various Python tools for use with BlueSky at the APS

* http://nsls-ii.github.io/
* https://github.com/NSLS-II/bluesky

## Provides

* `APS_BlueSky_tools.filewriters.SpecWriterCallback`
* ...

## Package Information

item              | description
------------------|--------------------------------
**author**        | Pete R. Jemian
**email**         | jemian@anl.gov
**copyright**     | 2017-, Pete R. Jemian
[**license**](APS_BlueSky_tools/LICENSE) | ANL OPEN SOURCE LICENSE
[**documentation**](http://APS_BlueSky_tools.readthedocs.io) | http://APS_BlueSky_tools.readthedocs.io
**source**        | https://github.com/BCDA-APS/APS_BlueSky_tools

## Release Badges

item  | description
------|--------------
latest tag | -tba-
latest release | -tba-
PyPI version | -tba-
